-- Pin by Jadya
-- EU - Well of Eternity
local addonName, addonTable = ...
local L = addonTable.L

local settings = addonTable.settings
local notes = addonTable.NoteFunctions

-- screen W/H
local sW, sH

function Pin_InitAnchorUpdate()
 sW = GetScreenWidth()
 sH = GetScreenHeight()
end

function Pin_AnchorUpdate(note)
 local x, y = GetCursorPosition()
 local ox, oy
 
 x = x / UIParent:GetScale()
 y = y / UIParent:GetScale()

 y = sH -y

 -- reduce cursor position to 0..1 for clarity purposes
 local pX = x / sW
 local pY = y / sH

 local anchor

 note:ClearAllPoints()

 if pX < 0.5 and pY < 0.5 then -- topleft quadrant
  if pX < pY then
   anchor = "LEFT"
   ox = 0
   oy = -y + sH / 2
  else
   anchor = "TOP"
   oy = 0
   ox = x - sW / 2
  end
 elseif pX >= 0.5 and pY < 0.5 then -- topright quadrant
  if 1 - pX < pY then
   anchor = "RIGHT"
   ox = 0
   oy = -y + sH / 2
  else
   anchor = "TOP"
   oy = 0
   ox = x - sW / 2
  end
 elseif pX < 0.5 and pY >= 0.5 then -- bottomleft quadrant
  if pX < 1 - pY then
   anchor = "LEFT"
   ox = 0
   oy = -y + sH / 2
  else
   anchor = "BOTTOM"
   oy = 0
   ox = x - sW / 2
  end
 elseif pX >= 0.5 and pY >= 0.5 then -- bottomright quadrant
  if 1 - pX < 1 - pY then
   anchor = "RIGHT"
   ox = 0
   oy = -y + sH / 2
  else
   anchor = "BOTTOM"
   oy = 0
   ox = x - sW / 2
  end
 end

 note:SetPoint(anchor, UIParent, anchor, ox, oy)
 notes:AnchorPin(note, anchor)
end

function Pin_OnDragStop(self)
 self:GetParent():StopMovingOrSizing()
 self:SetScript("OnUpdate", nil)
 notes:Save(self:GetParent())
end

function Pin_OnEditFocusGained(self)
 local note = self:GetParent()
 if note.fresh then
  note.text:SetText("")
  notes:SetAttr(note, "fresh", nil)
 end
end
 
function Pin_OnTextChanged(self, input)
 local note = self:GetParent()

 notes:UpdateSize(note)
 PinSaves.notes[note.id].text = self:GetText()
end

function Pin_OnMouseUp(self, button)
 if button == "RightButton" then
  Pin_Settings(self:GetParent())
 else
  notes:Toggle(self:GetParent())
 end
end

function PinGroupListButton_Visibility_OnClick(self)
 local p = self:GetParent()

 settings:CycleGroupVisibilityByListIndex(p.index)
end

function PinGroupListButton_OnLoad(self)
 SaregonWidgets:ListButton_OnLoad(self)
 self.func = settings.ShowEditBox
end

function Pin_ListboxPinsButton_OnEnter(self)
 if not self.pin then return end
 
 local p = self.pin:GetPoint()
 local side = notes:GetSide(p)

 self.pin.highlight_arrow:ClearAllPoints()
 
 if side == "LEFT" then
  self.pin.highlight_arrow:SetPoint("LEFT", self.pin, "RIGHT")
  self.pin.highlight_arrow:SetRotation(1.5708)
 elseif side == "TOP" then
  self.pin.highlight_arrow:SetPoint("TOP", self.pin, "BOTTOM")
  self.pin.highlight_arrow:SetRotation(0)
 elseif side == "RIGHT" then
  self.pin.highlight_arrow:SetPoint("RIGHT", self.pin, "LEFT")
  self.pin.highlight_arrow:SetRotation(4.71239)
 else
  self.pin.highlight_arrow:SetPoint("BOTTOM", self.pin, "TOP")
  self.pin.highlight_arrow:SetRotation(3.14159)
 end
 
 self.pin.highlight_arrow:Show()
end

function Pin_ListboxPinsButton_OnLeave(self)
 if not self.pin then return end
 
 self.pin.highlight_arrow:Hide()
end





